__version__ = "0.3.0"

"""
Changelog:
0.3.0- Changed call structure- separated things a bit.
0.2.1- Added some of the missing tests. Updated readmes.
0.2.0- Name change and added endpoints market orders, make account,
    plus various other bug fixes. Also added rate limiting fuctionality.

"""
